@@ -28,6 +28,9 @@ TWEAK_GROUP_THEME = _("Theme")
 TWEAK_GROUP_DESKTOP = _("Desktop")
 TWEAK_GROUP_WINDOWS = _("Windows")
 
+#translate this the same as the name of the file manager (nautilus)
+TWEAK_GROUP_FILES = _("Files")
+
 LOG = logging.getLogger(__name__)
 
 class Tweak:
@@ -35,6 +38,7 @@ class Tweak:
         self.name = name
         self.description = description
         self.group_name = options.get("group_name",_("Miscellaneous"))
+        self.loaded = True
 
         self._search_cache = None
 
@@ -148,6 +152,8 @@ class TweakModel(Gtk.ListStore):
         self._tweak_group_names[tweakgroup.name] = tweakgroup
 
     def add_tweak_auto_to_group(self, tweak):
+        if not tweak.loaded:
+            return
         name = tweak.group_name
         try:
             group = self._tweak_group_names[name]
